# pyvpsq

[![ci](https://img.shields.io/github/actions/workflow/status/cetteup/pyvpsq/ci.yml?label=ci)](https://github.com/cetteup/pyvpsq/actions?query=workflow%3Aci)
[![License](https://img.shields.io/github/license/cetteup/pyvpsq)](/LICENSE)
[![Package](https://img.shields.io/pypi/v/pyvpsq)](https://pypi.org/project/pyvpsq/)
[![Last commit](https://img.shields.io/github/last-commit/cetteup/pyvpsq)](https://github.com/cetteup/pyvpsq/commits/main)

Simple Python library for querying Valve's principal servers and their game servers
